<?php

namespace Drupal\usercentrics\Controller;

use Drupal\Core\Config\Entity\DraggableListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\usercentrics\Utility\UsercentricsHelper;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a listing of Usercentrics apps.
 */
class UsercentricsAppListBuilder extends DraggableListBuilder {

  /**
   * The available purposes.
   *
   * @var array
   */
  protected $availablePurposes;

  /**
   * {@inheritdoc}
   */
  protected $limit = FALSE;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'usercentrics_app_list';
  }

  /**
   * Constructs a new UsercentricsAppListBuilder object.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type.
   * @param \Drupal\Core\Entity\EntityStorageInterface $storage
   *   The entity storage.
   * @param \Drupal\usercentrics\Utility\UsercentricsHelper $helper
   *   The Usercentrics helper.
   */
  public function __construct(EntityTypeInterface $entity_type, EntityStorageInterface $storage, UsercentricsHelper $helper) {
    parent::__construct($entity_type, $storage);
  }

  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    return new static(
      $entity_type,
      $container->get('entity_type.manager')->getStorage($entity_type->id()),
      $container->get('usercentrics.helper')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['status'] = $this->t('Status', [], ['context' => 'usercentrics']);
    $header['uc_id'] = $this->t('Usercentrics ID', [], ['context' => 'usercentrics']);
    $header['label'] = $this->t('Label', [], ['context' => 'usercentrics']);

    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /** @var \Drupal\usercentrics\UsercentricsAppInterface $entity */
    $row['status']['#markup'] = $entity->status() ? $this->t('Enabled', [], ['context' => 'usercentrics']) : $this->t('Disabled', [], ['context' => 'usercentrics']);
    $row['uc_id']['#markup'] = $entity->ucId();
    $row['label'] = $entity->label();

    return $row + parent::buildRow($entity);
  }

}
